FtsNear class base

A helper class for composing FTS NEAR groups.

Inheritance

Constructors

FtsNear(List<FtsP> phrases, [int n = -1])
Composes an FTS NEAR group and wraps the result.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
The FTS query construct wrapped by this FtsQuery instance.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed binary NOT operator.
inherited
parens() FtsQ
Encloses this FTS query construct in parentheses and returns the result.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed AND operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed OR operator.
inherited

Static Methods

compose(List<FtsP> phrases, int n) String
Composes and returns an FTS NEAR group.