FtsNear constructor

FtsNear(
  1. List<FtsP> phrases, [
  2. int n = -1
])

Composes an FTS NEAR group and wraps the result.

If the n argument is greater than or equal to zero, the composed NEAR group will have n as its N parameter.

Implementation

FtsNear(List<FtsP> phrases, [int n = -1])
  : super(FtsNear.compose(phrases, n));