FtsPhrase class base

A helper class for composing FTS phrases.

Inheritance

Constructors

FtsPhrase(String str)
Wraps the FTS phrase provided in the str argument.
FtsPhrase.quote(String str)
Composes a quoted FTS string and wraps the result.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
The FTS query construct wrapped by this FtsQuery instance.
finalinherited

Methods

initial() FtsP
Makes this phrase an initial-token-query phrase and returns the result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed binary NOT operator.
inherited
parens() FtsQ
Encloses this FTS query construct in parentheses and returns the result.
inherited
prefix() FtsP
Makes the last token of this phrase a prefix token and returns the result.
toString() String
A string representation of this object.
inherited

Operators

operator &(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed AND operator.
inherited
operator +(FtsP p) FtsP
Concatenates this phrase with p and returns the resulting phrase.
operator ==(Object other) bool
The equality operator.
inherited
operator |(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed OR operator.
inherited