FtsSide class base

A base helper class for composing FTS column filters.

Inheritance
Implementers

Constructors

FtsSide(String str)
Wraps the FTS column filter construct provided in the str argument.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
The FTS query construct wrapped by this FtsQuery instance.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed binary NOT operator.
inherited
parens() FtsQ
Encloses this FTS query construct in parentheses and returns the result.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed AND operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(FtsQ q) FtsQ
Composes and returns a parenthesis-enclosed OR operator.
inherited

Static Methods

compose(List<String> columns, FtsQ query) String
Composes and returns a base FTS column filter construct.