FullId constructor

FullId(
  1. int rowid,
  2. Object keyid
)

Creates a FullId instance initialized with the given rowid and keyid.

The rowid must be greater than zero. The keyid must be either a num or a String.

Implementation

FullId(this.rowid, this.keyid) {
  checkState(rowid > 0);
  checkState(keyid is num || keyid is String);
}