props property
The list of properties that will be used to determine whether two instances are equal.
Implementation
@override
StdList get props => [rowid, keyid];
The list of properties that will be used to determine whether two instances are equal.
@override
StdList get props => [rowid, keyid];