KeyId class base

A subclass of SqlId that has only the keyid unique identifier.

Inheritance

Constructors

KeyId(Object keyid)
Creates a KeyId instance initialized with the given keyid.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasKeyId bool
Whether this SqlId instance has the keyid unique identifier.
no setterinherited
hasRowId bool
Whether this SqlId instance has the rowid unique identifier.
no setterinherited
keyid Object
The value of the keyid unique identifier.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rowid int
The value of the rowid unique identifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Overrides the Equatable.stringify property to true.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPropsString() String
Returns a string representation of the props list.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited