movePrevious method
Advances the iterator to the previous element in the iteration.
Implementation
bool movePrevious() => move(QueryDirection.reverse);
Advances the iterator to the previous element in the iteration.
bool movePrevious() => move(QueryDirection.reverse);