columns property
The list of IndexColumns that form the index.
See PartialIndex for information on which rows are included in the index.
Implementation
final IndexColumns columns;
The list of IndexColumns that form the index.
See PartialIndex for information on which rows are included in the index.
final IndexColumns columns;