checkDeactivated method
- @protected
inherited
Throws an Error if the state is not set to Deactivated.
Implementation
@protected
void checkDeactivated() => checkState(isDeactivated());
Throws an Error if the state is not set to Deactivated.
@protected
void checkDeactivated() => checkState(isDeactivated());