checkUndeactivated method
- @protected
inherited
Throws an Error if the state is not set to either Uninitialized or
Active.
Implementation
@protected
void checkUndeactivated() => checkState(isUndeactivated());
Throws an Error if the state is not set to either Uninitialized or
Active.
@protected
void checkUndeactivated() => checkState(isUndeactivated());