QueryDirection enum

The direction in which to select rows relative to a starting position.

Results returned by SQLite.query are formed by selecting rows in either a forward or reverse direction relative to the starting position provided by the application.

Inheritance
Available extensions

Values

forward → const QueryDirection

Select rows in the forward direction.

reverse → const QueryDirection

Select rows in the reverse direction.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueryDirection>
A constant List of the values in this enum, in order of their declaration.