QueryOrdering typedef

QueryOrdering = ({QuerySorting sorting, Sql sql})

The type of the elements in the order argument of SQLite.prepare.

This type is a record of an Sql and a QuerySorting. It defines an ordering expression (which could be simply a column name) and sorting.

Implementation

typedef QueryOrdering = ({Sql sql, QuerySorting sorting});