QueryRow typedef

QueryRow = ({QueryRowColumns columns, FullId id, QueryRowOrdered ordered})

The type of the elements in a list returned by SQLite.query.

This type is a record containing values of FullId, QueryRowOrdered, and QueryRowColumns. See SQLite.prepare for a description of what influences the content of every QueryRow in a result set.

Implementation

typedef QueryRow = ({
  FullId id,
  QueryRowOrdered ordered,
  QueryRowColumns columns,
});