QueryRowColumns typedef

QueryRowColumns = List<Object?>

The type of the columns field of QueryRow.

This type is a List of nullable Objects. For every row of a result set, the content of this list is formed by the values evaluated from the expressions in the columns argument of the SQLite.prepare method.

Implementation

typedef QueryRowColumns = List<Object?>;