QueryRowOrdered typedef

QueryRowOrdered = List<Kind>

The type of the ordered field of QueryRow.

This type is a List of Objects. For every row of a result set, the content of this list is formed by the values evaluated from the expressions in the order argument of the SQLite.prepare method.

Implementation

typedef QueryRowOrdered = List<Object>;