QuerySorting enum

Sort the rows of a query in ascending or descending order.

Queries prepared by SQLite.prepare are always sorted using:

  • optional application-provided sorting criteria (which include the order);
  • the last mandatory sorting column, which is always sorted in ascending order.

See also: queryOrdering and QueryDistinction.

Inheritance
Available extensions

Values

ascending → const QuerySorting

Sort the rows of a query in ascending order.

descending → const QuerySorting

Sort the rows of a query in descending order.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QuerySorting>
A constant List of the values in this enum, in order of their declaration.