RowId class base

A subclass of SqlId that has only the rowid unique identifier.

Inheritance

Constructors

RowId(int rowid)
Creates a RowId instance initialized with the given rowid.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasKeyId bool
Whether this SqlId instance has the keyid unique identifier.
no setterinherited
hasRowId bool
Whether this SqlId instance has the rowid unique identifier.
no setterinherited
keyid Object?
The value of the keyid unique identifier.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rowid int
The value of the rowid unique identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Overrides the Equatable.stringify property to true.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPropsString() String
Returns a string representation of the props list.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited