SQLite constructor

SQLite(
  1. String file,
  2. Scheme scheme
)

Constructs a new instance of the class for the on-disk database.

The class follows the ActorBase pattern, which means that the newly constructed instance is in an uninitialized state and is not ready to be used until the initialize method is called. To free the resources and close the database, the deactivate method must be called.

The file and scheme arguments represent a path to a database file and the database Scheme that the application requires, respectively.

Implementation

SQLite(String file, this.scheme) : filename = file;