checkUninitialized method
- @protected
inherited
Throws an Error if the state is not set to Uninitialized.
Implementation
@protected
void checkUninitialized() => checkState(isUninitialized());
Throws an Error if the state is not set to Uninitialized.
@protected
void checkUninitialized() => checkState(isUninitialized());