updated method
Returns whether a row was inserted, updated, or deleted.
Implementation
@protected
bool updated() {
int count = _database!.updatedRows;
checkState(count == 0 || count == 1);
return count == 1;
}
Returns whether a row was inserted, updated, or deleted.
@protected
bool updated() {
int count = _database!.updatedRows;
checkState(count == 0 || count == 1);
return count == 1;
}