prepare abstract method

  1. @protected
int prepare()

Calls SQLite.prepare and returns the resulting QueryId.

This method has zero arguments and is invoked during the execution of the SQLiteQuery class constructor. However, it is possible to collect some or all query configuration parameters (i.e., arguments to SQLite.prepare) via the constructor of a derived class into class properties and access them here (see SQLiteQuery for an example).

Implementation

@protected
QueryId prepare();