kSchemaVersion constant
String
const kSchemaVersion
The key for the schema version part of the overall scheme version map.
Implementation
static const String kSchemaVersion = "schemaVersion";
The key for the schema version part of the overall scheme version map.
static const String kSchemaVersion = "schemaVersion";