partialIndexes property

PartialIndexes partialIndexes
final

A list of the partial index descriptions.

If the PartialIndex.columns of an index in this list change, the index's PartialIndex.version must be increased to trigger a scheme migration. More formally, if the map composed of the name-version pairs of the partialIndexes has changed, then the overall scheme version changes and a scheme migration procedure is triggered.

If there is a need to create or rename an index, it is best to avoid new names that were used in old scheme versions, because a coincidence might arise if, e.g., one index is removed in the application update X and another is introduced immediately after under the same name and version in the update X+1 while a user skips the update X but installs X+1.

Implementation

final PartialIndexes partialIndexes;