revision property
The application-provided revision number for this scheme description.
Changing this number changes the overall scheme version, which triggers a scheme migration procedure.
Implementation
final int revision;
The application-provided revision number for this scheme description.
Changing this number changes the overall scheme version, which triggers a scheme migration procedure.
final int revision;