upgrader property
The callbacks invoked during scheme migration.
These callbacks are invoked only when the revision changes.
Implementation
final DatabaseUpgrader? upgrader;
The callbacks invoked during scheme migration.
These callbacks are invoked only when the revision changes.
final DatabaseUpgrader? upgrader;