SchemeElement class base

A base class for classes that describe aspects of a Scheme.

Every derived class has two common properties defined here: the version of the description the class provides and the name of that description. Changes to other properties in derived classes must be accompanied by an increase in the version to trigger a scheme migration.

Implementers
Annotations
  • @immutable

Constructors

SchemeElement({required int version, required String name})
Creates a SchemeElement initialized with the given version and name.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
A string representing the name of the provided description.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
An integer representing the version of the provided description.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited