getElementsMap method
Returns a map representing the overall version of the SchemeElements.
Implementation
@protected
Map<String, int> getElementsMap(StdMap scheme, String elements) =>
(scheme[elements] as StdMap? ?? {}).cast<String, int>();
Returns a map representing the overall version of the SchemeElements.
@protected
Map<String, int> getElementsMap(StdMap scheme, String elements) =>
(scheme[elements] as StdMap? ?? {}).cast<String, int>();