SearchColumn class base

A description used within a SearchIndex to define an FTS column.

A SearchColumn instance describes a single column. The description consists of the column's name as well as its unindexed and json statuses.

Annotations
  • @immutable

Constructors

SearchColumn(String name, {bool unindexed = false, bool json = false})
Creates a description of an FTS column using the given parameters.

Properties

hashCode int
The hash code for this object.
no setterinherited
json bool
Whether to store values of the described column as binary JSON.
final
name String
The name of the described column.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unindexed bool
Whether the described column is excluded from indexing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited