SearchIndex constructor

SearchIndex({
  1. required int version,
  2. required String name,
  3. required SearchColumns columns,
  4. required SearchRowGetters getters,
})

Creates a description of an FTS index using the given parameters.

Every key in a SearchRow map returned by the getters must match the name of one of the columns, and the size of the SearchRow map must match the number of columns.

See also: SchemeElement.new.

Implementation

SearchIndex({
  required super.version,
  required super.name,
  required this.columns,
  required this.getters,
});