columns property
The list of SearchColumns that form the FTS index.
See SearchIndex for information on how this property relates to the getters property.
Implementation
final SearchColumns columns;
The list of SearchColumns that form the FTS index.
See SearchIndex for information on how this property relates to the getters property.
final SearchColumns columns;