getters property
The map associating Kinds of the FTS index with SearchRowGetters.
See SearchIndex for information on how this property relates to the columns property.
Implementation
final SearchRowGetters getters;
The map associating Kinds of the FTS index with SearchRowGetters.
See SearchIndex for information on how this property relates to the columns property.
final SearchRowGetters getters;