SearchIndexUpdater class base

SQL statements associated with a SearchIndex.

A SearchIndexUpdater instance is maintained by the Scheme that owns the corresponding SearchIndex. The instance's SQL statements are used by the library to automatically insert, update, and delete rows in the FTS index as dictated by modifications to the mapping table or by scheme migrations.

See also: SearchIndex.updater.

Constructors

SearchIndexUpdater(SearchIndex index)
Creates a SearchIndexUpdater for the given FTS index description.

Properties

delete → CommonPreparedStatement
The DELETE SQL statement for the FTS index.
no setter
hashCode int
The hash code for this object.
no setterinherited
index SearchIndex
The SearchIndex with which this SearchIndexUpdater is associated.
final
insert → CommonPreparedStatement
The INSERT SQL statement for the FTS index.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlite SQLite
The SQLite reference initialized by the Scheme.
latefinal
update → CommonPreparedStatement
The UPDATE SQL statement for the FTS index.
no setter

Methods

checkActive() → void
Throws an Error if the state is not set to Active.
inherited
checkDeactivated() → void
Throws an Error if the state is not set to Deactivated.
inherited
checkInitialized() → void
Throws an Error if the state is not set to either Active or Deactivated.
inherited
checkUndeactivated() → void
Throws an Error if the state is not set to either Uninitialized or Active.
inherited
checkUninitialized() → void
Throws an Error if the state is not set to Uninitialized.
inherited
columnsDdlSql() String
Returns a string of the column names for use in DDL statements.
columnsSql() String
Returns a comma-separated string of the quoted names of the columns.
deactivate() → void
A public interface for object deactivation.
inherited
dispose() → void
Called by deactivate; should contain the actual object deactivation code.
initialize() → void
A public interface for object initialization.
inherited
isActive() bool
Whether the state is set to Active.
inherited
isDeactivated() bool
Whether the state is set to Deactivated.
inherited
isInitialized() bool
Whether the state is set to either Active or Deactivated.
inherited
isUndeactivated() bool
Whether the state is set to either Uninitialized or Active.
inherited
isUninitialized() bool
Whether the state is set to Uninitialized.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parametersSql() String
Returns a string of the named SQL parameters using the column ordinals.
propose() → void
Called by initialize; should contain the actual object initialization code.
raiseInactive() → void
Throws an InactiveActorException if the state is no longer set to Active.
inherited
searchRowToParameters(SearchRow row) Map<String, Object>
Converts a SearchRow to a value binding map of named SQL parameters.
setActive() → void
Sets the state to Active.
inherited
setDeactivated() → void
Sets the state to Deactivated.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited