checkActive method
- @protected
inherited
Throws an Error if the state is not set to Active.
Implementation
@protected
void checkActive() => checkState(isActive());
Throws an Error if the state is not set to Active.
@protected
void checkActive() => checkState(isActive());