checkInitialized method
- @protected
inherited
Throws an Error if the state is not set to either Active or
Deactivated.
Implementation
@protected
void checkInitialized() => checkState(isInitialized());
Throws an Error if the state is not set to either Active or
Deactivated.
@protected
void checkInitialized() => checkState(isInitialized());