columnsDdlSql method
Returns a string of the column names for use in DDL statements.
Implementation
String columnsDdlSql() => index.columns
.map((var c) => sqlIdentifier(c.name) + (c.unindexed ? " UNINDEXED" : ""))
.join(", ");
Returns a string of the column names for use in DDL statements.
String columnsDdlSql() => index.columns
.map((var c) => sqlIdentifier(c.name) + (c.unindexed ? " UNINDEXED" : ""))
.join(", ");