columnsSql method
Returns a comma-separated string of the quoted names of the columns.
Implementation
String columnsSql() =>
index.columns.map((var c) => sqlIdentifier(c.name)).join(", ");
Returns a comma-separated string of the quoted names of the columns.
String columnsSql() =>
index.columns.map((var c) => sqlIdentifier(c.name)).join(", ");