isUndeactivated method
Whether the state is set to either Uninitialized or Active.
Implementation
bool isUndeactivated() => !isDeactivated();
Whether the state is set to either Uninitialized or Active.
bool isUndeactivated() => !isDeactivated();