SearchRowGetter typedef

SearchRowGetter = SearchRow Function(Object value)

The signature of a callback that converts a JSON value into a SearchRow.

These callbacks are application-defined and are invoked when search indexes (FTS) are created or updated. A callback is associated with a Kind via an entry in a SearchRowGetters map, which is passed to SearchIndex.new.

After a new JSON value of a particular Kind is inserted or updated in SQLite.apply via Transaction, the corresponding callback receives that value. The callback must extract the fields to be indexed from the value and return them as a SearchRow.

These callbacks may also be called during Scheme migrations.

Implementation

typedef SearchRowGetter = SearchRow Function(Object value);