SearchRowGetters typedef

SearchRowGetters = Map<Kind, SearchRowGetter>

The type of the getters argument to SearchIndex.new.

This type is a Map of Kinds to SearchRowGetters. For a particular SearchIndex, it associates each Kind that this index deals with and the corresponding SearchRowGetter that provides SearchRows for JSON values of this Kind.

Implementation

typedef SearchRowGetters = Map<Kind, SearchRowGetter>;