SqlId class sealed

A sealed class representing the unique ID of a mapping table row.

The mapping table has an SQLite-mandated built-in rowid column and a library-defined keyid column. Both rowid and keyid, independent of each other, uniquely identify each row in this table. During row insertion, rowid values are automatically generated and assigned by SQLite, while keyid values are generated by the application and passed to this library. For example, keyid values may be hashes, UUIDs, or URIs.

See also: RowId, KeyId, and FullId.

Implementers
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
hasKeyId bool
Whether this SqlId instance has the keyid unique identifier.
no setter
hasRowId bool
Whether this SqlId instance has the rowid unique identifier.
no setter
keyid Object?
The value of the keyid unique identifier.
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
rowid int
The value of the rowid unique identifier.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Overrides the Equatable.stringify property to true.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPropsString() String
Returns a string representation of the props list.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited