SqlJsonQuote class base

A helper class for composing a json_quote function call.

Inheritance

Constructors

SqlJsonQuote(Sql x)
Composes and wraps a json_quote function call.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
The SQL construct wrapped by this Sql instance.
finalinherited

Methods

between(Sql a, Sql b) Sql
Composes and returns a parenthesis-enclosed BETWEEN operator.
inherited
concat(Sql x) Sql
Composes and returns a parenthesis-enclosed || operator.
inherited
equal(Sql x) Sql
Composes and returns a parenthesis-enclosed == operator.
inherited
glob(Sql x) Sql
Composes and returns a parenthesis-enclosed GLOB operator.
inherited
inX(Sql x) Sql
Composes and returns a parenthesis-enclosed IN operator.
inherited
isEqual(Sql x) Sql
Composes and returns a parenthesis-enclosed IS operator.
inherited
isNotEqual(Sql x) Sql
Composes and returns a parenthesis-enclosed IS NOT operator.
inherited
like(Sql x) Sql
Composes and returns a parenthesis-enclosed binary LIKE operator.
inherited
likeEscape(Sql a, Sql b) Sql
Composes and returns a parenthesis-enclosed ternary LIKE operator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Sql
Composes and returns a parenthesis-enclosed NOT operator.
inherited
notEqual(Sql x) Sql
Composes and returns a parenthesis-enclosed != operator.
inherited
toString() String
A string representation of this object.
inherited
trim() Sql
Removes the enclosing parentheses, if present, and returns the result.
inherited

Operators

operator %(Sql x) Sql
Composes and returns a parenthesis-enclosed % operator.
inherited
operator &(Sql x) Sql
Composes and returns a parenthesis-enclosed AND operator.
inherited
operator *(Sql x) Sql
Composes and returns a parenthesis-enclosed * operator.
inherited
operator +(Sql x) Sql
Composes and returns a parenthesis-enclosed + operator.
inherited
operator -(Sql x) Sql
Composes and returns a parenthesis-enclosed binary - operator.
inherited
operator /(Sql x) Sql
Composes and returns a parenthesis-enclosed / operator.
inherited
operator <(Sql x) Sql
Composes and returns a parenthesis-enclosed < operator.
inherited
operator <=(Sql x) Sql
Composes and returns a parenthesis-enclosed <= operator.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(Sql x) Sql
Composes and returns a parenthesis-enclosed > operator.
inherited
operator >=(Sql x) Sql
Composes and returns a parenthesis-enclosed >= operator.
inherited
operator unary-() Sql
Composes and returns a parenthesis-enclosed unary - operator.
inherited
operator |(Sql x) Sql
Composes and returns a parenthesis-enclosed OR operator.
inherited