delete method

void delete(
  1. SqlId id
)

Adds a delete edit to the memory buffer.

When this Transaction is written, processing of this edit will delete an existing JSON value identified by the id from a database.

Implementation

void delete(SqlId id) => _entries.add(_TxDelete(id));