insert method

void insert(
  1. KeyId id,
  2. Object value
)

Adds an insert edit to the memory buffer.

When this Transaction is written, processing of this edit will insert a new JSON value identified by the id into a database.

Implementation

void insert(KeyId id, Object value) => _entries.add(_TxInsert(id, value));