update method

void update(
  1. SqlId id,
  2. Object value
)

Adds an update edit to the memory buffer.

When this Transaction is written, processing of this edit will update an existing JSON value identified by the id with a new value in a database.

Implementation

void update(SqlId id, Object value) => _entries.add(_TxUpdate(id, value));