VirtualColumn constructor

VirtualColumn({
  1. required int version,
  2. required String name,
  3. required KindList kinds,
  4. required Sql sql,
})

Creates a description of a virtual column using the given parameters.

The value of the virtual column is equal to the result of the sql expression. This expression is evaluated only for rows whose kinds are included in the kinds property. Rows of other kinds will have NULL as the value of the virtual column.

See also: SchemeElement.new.

Implementation

VirtualColumn({
  required super.version,
  required super.name,
  required this.kinds,
  required this.sql,
});