kinds property

KindList kinds
final

The kinds of rows to which the evaluation of the column value is limited.

See VirtualColumn for information on how this property relates to the sql property.

Implementation

final KindList kinds;