sql property

Sql sql
final

The expression whose result forms the value of the virtual column.

See VirtualColumn for information on how this property relates to the kinds property.

Implementation

final Sql sql;