ftsTermJoiner top-level constant

String const ftsTermJoiner

A special character used by ftsTerm to replace non-token characters.

The ftsTerm function creates an extended FTS token by replacing character sequences that do not conform to reFtsTermToken with this character.

This character can also be used as an additional separator between word sequences in FTS fields. Such an approach helps prevent a word ending one sequence from being immediately adjacent to a word starting another sequence, which is beneficial for certain FTS queries. For example, the following text fragment will not yield results for the hot + dog FTS query:

"… hot $ftsTermJoiner dog …"

Implementation

const String ftsTermJoiner = "\uEEEE";