keyDefinition top-level constant

String const keyDefinition

The keyid value of the row that contains a stored scheme.

A Scheme is serialized and stored in the scheme table, with this value used for the keyid column.

Implementation

const String keyDefinition = "definition";