queryDefaultLimit top-level constant

int const queryDefaultLimit

A limit for SQLite.prepare used internally during scheme migration.

This limit is used internally by the library as an argument to SQLite.prepare in cases where a potentially large set of rows must be processed — namely, during scheme migration.

Implementation

const int queryDefaultLimit = 50;