reFtsTermToken top-level property
A regexp matching an extended FTS token.
It is defined as a sequence of characters from the L, N, Co, P, and S Unicode categories. These categories correspond to the behavior of the "unicode61" tokenizer configured by this library. An extended token can be formed using the ftsTerm function, assigned to FTS fields as part of a string or as a whole string, and queried as an indivisible unit.
See also: tokenCategories and reFtsTextToken.
Implementation
final RegExp reFtsTermToken = RegExp(
"[\\p{L}\\p{N}\\p{Co}\\p{P}\\p{S}]+",
unicode: true,
);