reFtsTextToken top-level property

RegExp reFtsTextToken
final

A regexp matching a standard FTS token.

It is defined as a sequence of characters from the L, N, and Co Unicode categories. These categories correspond to the default behavior of the "unicode61" tokenizer. The ftsText preprocessing function uses this regexp to identify standard FTS tokens.

See also: tokenCategories and reFtsTermToken.

Implementation

final RegExp reFtsTextToken = RegExp("[\\p{L}\\p{N}\\p{Co}]+", unicode: true);