SearchQueryConverter constructor

SearchQueryConverter({
  1. required List<String> columns,
  2. required Map<String, List<String>> aliases,
})

Creates a new SearchQueryConverter with the given arguments.

The arguments are as follows:

  • columns is a list of the actual names of the FTS table columns to which FTS queries generated by this parser are limited;
  • aliases is a Map that defines custom column names recognized by this parser and maps each name to a substitution list of one or more actual column names found in columns.

Names in columns are not recognized by the parser (unless they appear as keys in aliases); only column names defined as keys in aliases are.

Implementation

SearchQueryConverter({required this.columns, required this.aliases});