columns property
A list of the actual names of the FTS table columns.
All FTS queries generated by this parser operate either on these columns or, depending on the query, on a subset of these columns. These names are not recognized by the parser (unless they appear as keys in aliases).
Implementation
final List<String> columns;