SearchQueryConverterException class
Properties
-
failure
→ Failure
-
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
message
→ String
-
A message describing the format error.
no setterinherited
-
offset
→ int
-
The offset in source where the error was detected.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ String
-
The actual source input which caused the error.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited