A mixin whose methods are invoked by the scheme migration as callbacks.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
after(
{required bool success}) → void - This callback is invoked after the scheme migration finishes.
-
before(
int storedRevision, int actualRevision, SQLite sqlite) → void - This callback is invoked before the scheme migration starts.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited