after abstract method
This callback is invoked after the scheme migration finishes.
The success argument is true if the migration was successful. This
method and the migration share the same transaction.
Implementation
void after({required bool success});