before abstract method
This callback is invoked before the scheme migration starts.
After calling this method, the migration will occur from storedRevision
(the stored on-disk revision of the database) to actualRevision (the
actual revision the application is expecting). This method and the
migration share the same transaction.
Implementation
void before(int storedRevision, int actualRevision, SQLite sqlite);