FtsPhrase class

Inheritance

Constructors

FtsPhrase(String string)
FtsPhrase.quote(String string)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
finalinherited

Methods

initial() FtsP
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not(FtsQ q) FtsQ
inherited
parens() FtsQ
inherited
prefix() FtsP
toString() String
A string representation of this object.
inherited

Operators

operator &(FtsQ q) FtsQ
inherited
operator +(FtsP p) FtsP
operator ==(Object other) bool
The equality operator.
inherited
operator |(FtsQ q) FtsQ
inherited