FtsQuery class base
A base helper class for composing FTS queries.
This wrapper class and its descendants do not prevent the composition of
invalid FTS queries; the goal is only to simplify the composition process by
avoiding direct string concatenation and interpolation. For example, the
following fragment composes an FTS query using FtsI and FtsP.quote,
encloses it in a table-valued function call using SqlT and SqlS, and
finally passes the "\"timetable\"('(\"months\": \"january\")')" string to
the SQLite.prepare function:
FtsQ ftsQuery = FtsI(["months"], FtsP.quote("january"));
QueryId qid = sqlite.prepare(
search: SqlT("timetable", SqlS(ftsQuery)),
/* ... */
See also: Sql.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed binary
NOToperator. -
parens(
) → FtsQ - Encloses this FTS query construct in parentheses and returns the result.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed
ANDoperator. -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed
ORoperator.