FtsQuery class

Implementers
Annotations
  • @immutable

Constructors

FtsQuery(String str)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
str String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not(FtsQ q) FtsQ
parens() FtsQ
toString() String
A string representation of this object.
inherited

Operators

operator &(FtsQ q) FtsQ
operator ==(Object other) bool
The equality operator.
inherited
operator |(FtsQ q) FtsQ