FtsSide class base
A base helper class for composing FTS column filters.
- Inheritance
- Implementers
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed binary
NOToperator.inherited -
parens(
) → FtsQ -
Encloses this FTS query construct in parentheses and returns the result.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed
ANDoperator.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
FtsQ q) → FtsQ -
Composes and returns a parenthesis-enclosed
ORoperator.inherited