IndexColumn class base
A description used within a PartialIndex to define column indexing.
An IndexColumn instance describes a single column. The description consists of the column's name and its ascending status.
- Annotations
-
- @immutable
Constructors
- IndexColumn(String name, {bool ascending = true})
- Creates a description of column indexing using the given parameters.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited