PagedResultIterator class base
An Iterator that can iterate over pages of rows.
Constructors
- PagedResultIterator(PagedResult iterable)
-
Creates an Iterator for the given
iterable.
Properties
- current → QueryRows
-
The current element.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterable → PagedResult
-
The Iterable that this Iterator iterates over.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
move(
QueryDirection direction) → bool -
Advances the iterator in the specified
direction. -
moveNext(
) → bool -
Advances the iterator to the next element of the iteration.
override
-
movePrevious(
) → bool - Advances the iterator to the previous element in the iteration.
-
nextQuery(
QueryDirection direction) → QueryRows - Returns the next page of rows.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
QueryDirection direction, QueryRowPosition? start) → QueryRows - Returns the first page of rows.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited