PagedResultIterator class

Implemented types

Constructors

PagedResultIterator(PagedResult iterable)

Properties

current QueryRows
The current element.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
iterable PagedResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveNext() bool
Advances the iterator to the next element of the iteration.
override
movePrevious() bool
nextQuery(QueryDirection direction) QueryRows
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(QueryDirection direction, QueryRowPosition? start) QueryRows
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited