PartialIndex class base
A description used within a Scheme to define a partial index.
A partial index is added to the mapping table and is useful for speeding
up queries that operate on generated virtual columns. For a single-column
index, only rows with non-NULL values in that column are included in the
index. If multiple columns are specified, all of them within a single row
must be non-NULL for that row to be included in the index.
In the following fragment, a partial index named "numFlatware" is defined
for a single "numFlatware" column:
var pi = PartialIndex(
version: 1,
name: "numFlatware",
columns: [IndexColumn("numFlatware")],
);
/* ... */
See also: VirtualColumn.
- Inheritance
-
- Object
- SchemeElement
- PartialIndex
- Annotations
-
- @immutable
Constructors
- PartialIndex({required int version, required String name, required IndexColumns columns})
-
Creates a description for a partial index of the given
columns.
Properties
- columns → IndexColumns
-
The list of IndexColumns that form the index.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
A string representing the name of the provided description.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
An integer representing the version of the provided description.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited