PartialIndex constructor
PartialIndex({
- required int version,
- required String name,
- required IndexColumns columns,
Creates a description for a partial index of the given columns.
A row is excluded from the index if at least one of the specified
columns within that row is NULL.
See also: SchemeElement.new.
Implementation
PartialIndex({
required super.version,
required super.name,
required this.columns,
});