Query class base
Implements the capability of database querying.
This class encapsulates SQLite SELECT statements and is used internally by
the library to implement the functionality of the methods SQLite.prepare,
SQLite.free, and SQLite.query.
See also: QueryId.
Constructors
Properties
-
columns
→ List<
Sql> -
The additional columns to be retrieved.
final
- distinction → QueryDistinction
-
The last sorting column.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
The value for the
LIMITclause.final -
order
→ List<
QueryOrdering> -
The ordering of this query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → Sql?
-
The
FROMclause for full-text search queries.final - sqlite → SQLite
-
A reference to the SQLite instance for this query.
final
- where → Sql?
-
The
WHEREclause condition.final
Methods
-
checkActive(
) → void -
Throws an Error if the state is not set to
Active.inherited -
checkDeactivated(
) → void -
Throws an Error if the state is not set to
Deactivated.inherited -
checkInitialized(
) → void -
Throws an Error if the state is not set to either
ActiveorDeactivated.inherited -
checkUndeactivated(
) → void -
Throws an Error if the state is not set to either
UninitializedorActive.inherited -
checkUninitialized(
) → void -
Throws an Error if the state is not set to
Uninitialized.inherited -
deactivate(
) → void -
A public interface for object deactivation.
inherited
-
dispose(
) → void - Called by deactivate; should contain the actual object deactivation code.
-
getStrOrder(
QueryDirection direction) → String -
Returns
ORDER BYclause expressions. -
getStrSeek(
QueryDirection direction, {required bool first}) → String -
Returns a
WHEREclause condition for query seek-based pagination. -
initialize(
) → void -
A public interface for object initialization.
inherited
-
isActive(
) → bool -
Whether the state is set to
Active.inherited -
isDeactivated(
) → bool -
Whether the state is set to
Deactivated.inherited -
isInitialized(
) → bool -
Whether the state is set to either
ActiveorDeactivated.inherited -
isUndeactivated(
) → bool -
Whether the state is set to either
UninitializedorActive.inherited -
isUninitialized(
) → bool -
Whether the state is set to
Uninitialized.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
propose(
) → void -
Called by
initialize; should contain the actual object initialization code.inherited -
raiseInactive(
) → void -
Throws an
InactiveActorExceptionif the state is no longer set toActive.inherited -
run(
QueryParameters parameters, QueryDirection direction, QueryRowPosition? start) → ResultSet - Executes a query using the given query execution parameters.
-
setActive(
) → void -
Sets the state to
Active.inherited -
setDeactivated(
) → void -
Sets the state to
Deactivated.inherited -
statement(
QueryDirection direction, {required bool first}) → CommonPreparedStatement -
Caches (if not cached) and returns a prepared
SELECTstatement. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited