Query class base

Constructors

Query(SQLite sqlite, List<SqlX> columns, SqlX? search, SqlX? where, List<QueryOrdering> order, QueryDistinction distinction, int limit)

Properties

columns List<SqlX>
final
distinction QueryDistinction
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
order List<QueryOrdering>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
sqlite SQLite
final
where SqlX?
final

Methods

checkActive() → void
Throws an Error if the state is not set to Active.
inherited
checkDeactivated() → void
Throws an Error if the state is not set to Deactivated.
inherited
checkInitialized() → void
Throws an Error if the state is not set to either Active or Deactivated.
inherited
checkUndeactivated() → void
Throws an Error if the state is not set to either Uninitialized or Active.
inherited
checkUninitialized() → void
Throws an Error if the state is not set to Uninitialized.
inherited
deactivate() → void
A public interface for object deactivation.
inherited
dispose() → void
Called by deactivate; should contain the actual object deactivation code.
getStrOrder(QueryDirection direction) String
getStrSeek(QueryDirection direction, {required bool first}) String
initialize() → void
A public interface for object initialization.
inherited
isActive() bool
Whether the state is set to Active.
inherited
isDeactivated() bool
Whether the state is set to Deactivated.
inherited
isInitialized() bool
Whether the state is set to either Active or Deactivated.
inherited
isUndeactivated() bool
Whether the state is set to either Uninitialized or Active.
inherited
isUninitialized() bool
Whether the state is set to Uninitialized.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
propose() → void
Called by initialize; should contain the actual object initialization code.
inherited
raiseInactive() → void
Throws an InactiveActorException if the state is no longer set to Active.
inherited
run(QueryParameters parameters, QueryDirection direction, QueryRowPosition? start) → ResultSet
setActive() → void
Sets the state to Active.
inherited
setDeactivated() → void
Sets the state to Deactivated.
inherited
statement(QueryDirection direction, {required bool first}) → CommonPreparedStatement
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited