dispose method
Called by deactivate; should contain the actual object deactivation code.
If propose throws an Exception, the default Actor implementation
will call dispose to clean up even a partially initialized object.
Implementation
@protected
@override
void dispose() {
_forwardFirst?.close();
_forwardFirst = null;
_forwardNext?.close();
_forwardNext = null;
_reverseFirst?.close();
_reverseFirst = null;
_reverseNext?.close();
_reverseNext = null;
super.dispose();
}