propose method
- @protected
- @mustCallSuper
inherited
Called by initialize; should contain the actual object initialization
code.
The method is allowed to throw in the case of an error. If it throws an
Exception, the default Actor implementation will call dispose
afterward to clean up even a partially initialized object.
Implementation
@protected
@mustCallSuper
void propose() {
checkActive();
}