QueryDistinction enum
Whether to use rowid or keyid as the last mandatory sorting column.
Queries prepared by SQLite.prepare are always sorted, and each result row is uniquely identified by both rowid and keyid. In addition to optional application-provided sorting criteria, the last sorting column is always either rowid or keyid.
Values
- rowid → const QueryDistinction
-
Use rowid as the last mandatory sorting column.
- keyid → const QueryDistinction
-
Use keyid as the last mandatory sorting column.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QueryDistinction> - A constant List of the values in this enum, in order of their declaration.