QueryParameters typedef
A value binding map of named parameters for a query's SQL statement.
This type is a Map from Strings to Objects. It is one of the query execution parameters, which are the SQLite.query arguments.
Implementation
typedef QueryParameters = Map<String, Object>;