Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasKeyId
→ bool
-
no setterinherited
-
hasRowId
→ bool
-
no setterinherited
-
keyid
→ Object?
-
no setterinherited
-
props
→ StdList
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
rowid
→ int
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringify
→ bool
-
Overrides the
EquatableMixin.stringify property to true.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toPropsString()
→ String
-
Returns a string representation of the
props list.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited