SQLite class base

Constructors

SQLite(String filename, Scheme scheme)

Properties

filename String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme Scheme
final

Methods

apply(Transaction transaction, {bool savepoint = false}) int
begin() → void
beginSavepoint() → void
checkActive() → void
Throws an Error if the state is not set to Active.
inherited
checkDeactivated() → void
Throws an Error if the state is not set to Deactivated.
inherited
checkInitialized() → void
Throws an Error if the state is not set to either Active or Deactivated.
inherited
checkUndeactivated() → void
Throws an Error if the state is not set to either Uninitialized or Active.
inherited
checkUninitialized() → void
Throws an Error if the state is not set to Uninitialized.
inherited
commit() → void
commitSavepoint() → void
deactivate() → void
A public interface for object deactivation.
inherited
delete(SqlId id) bool
dispose() → void
Called by deactivate; should contain the actual object deactivation code.
domain(SqlId lower, SqlId upper) FullIdIterable
exists(SqlId id) bool
formatMakeColumn(MessageFormat message, String name, KindList kinds, SqlExpression expression) String
formatMakeIndex(MessageFormat message, String name, IndexColumns columns) String
free(QueryId id) → void
getStoredDefinition() → StdMap
initialize() → void
A public interface for object initialization.
inherited
insert(KeyId id, Object value) bool
isActive() bool
Whether the state is set to Active.
inherited
isDeactivated() bool
Whether the state is set to Deactivated.
inherited
isInitialized() bool
Whether the state is set to either Active or Deactivated.
inherited
isUndeactivated() bool
Whether the state is set to either Uninitialized or Active.
inherited
isUninitialized() bool
Whether the state is set to Uninitialized.
inherited
migrateScheme(StdMap stored, StdMap actual) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare({List<SqlX> columns = const [], SqlX? search, SqlX? where, List<QueryOrdering> order = const [], QueryDistinction distinction = QueryDistinction.rowid, int limit = -1}) QueryId
propose() → void
Called by initialize; should contain the actual object initialization code.
query(QueryId id, {QueryParameters parameters = const {}, QueryDirection direction = QueryDirection.forward, QueryRowPosition? start}) QueryRows
raiseInactive() → void
Throws an InactiveActorException if the state is no longer set to Active.
inherited
rollback() → void
rollbackSavepoint() → void
select(SqlId id) FullIdWithValue?
setActive() → void
Sets the state to Active.
inherited
setDeactivated() → void
Sets the state to Deactivated.
inherited
statement(String sql) → CommonPreparedStatement
toString() String
A string representation of this object.
inherited
update(SqlId id, Object value) bool
updated() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited