SQLite.inMemory constructor
SQLite.inMemory(
- Scheme scheme
Constructs a new instance of the class for the in-memory database.
The class follows the ActorBase pattern, which means that the newly
constructed instance is in an uninitialized state and is not ready to be
used until the initialize method is called. To free the resources and
close the database, the deactivate method must be called.
The scheme argument represents the database Scheme that the
application requires.
Implementation
SQLite.inMemory(this.scheme) : filename = null;