domain method
Returns all FullIds found in the database between lower and upper.
This method performs a range query to collect and return the ordered
FullIds of all mapping table rows whose keys lie between the lower
and upper bounds inclusively. The lower and upper arguments must
each be of either KeyId or FullId type. The returned FullIdIterable
contains all FullIds prefetched and sorted by FullId.keyid.
Implementation
FullIdIterable domain(SqlId lower, SqlId upper) {
QueryRows rows = query(
_domainQueryId,
parameters: {"@L": lower.keyid!, "@U": upper.keyid!},
);
return rows.map((var r) => r.id);
}