free method
Releases resources associated with the given QueryId.
This method deactivates the Query object associated with the given id
and releases all references to the object. The id becomes unusable and
will not be reused in the context of this SQLite instance.
Implementation
void free(QueryId id) {
checkActive();
if (_queries.remove(id) case var query?)
query.deactivate();
else
log.info("SQLite.free: query $id not found");
}