Methods
-
checkActive()
→ void
-
Throws an Error if the state is not set to
Active.
inherited
-
checkDeactivated()
→ void
-
Throws an Error if the state is not set to
Deactivated.
inherited
-
checkInitialized()
→ void
-
Throws an Error if the state is not set to either
Active or
Deactivated.
inherited
-
checkUndeactivated()
→ void
-
Throws an Error if the state is not set to either
Uninitialized or
Active.
inherited
-
checkUninitialized()
→ void
-
Throws an Error if the state is not set to
Uninitialized.
inherited
-
deactivate()
→ void
-
A public interface for object deactivation.
inherited
-
dispose()
→ void
-
Called by deactivate; should contain the actual object deactivation
code.
-
initialize()
→ void
-
A public interface for object initialization.
inherited
-
isActive()
→ bool
-
Whether the state is set to
Active.
inherited
-
isDeactivated()
→ bool
-
Whether the state is set to
Deactivated.
inherited
-
isInitialized()
→ bool
-
Whether the state is set to either
Active or Deactivated.
inherited
-
isUndeactivated()
→ bool
-
Whether the state is set to either
Uninitialized or Active.
inherited
-
isUninitialized()
→ bool
-
Whether the state is set to
Uninitialized.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
prepare()
→ QueryId
-
-
propose()
→ void
-
Called by initialize; should contain the actual object initialization
code.
-
raiseInactive()
→ void
-
Throws an
InactiveActorException if the state is no longer set to
Active.
inherited
-
setActive()
→ void
-
Sets the state to
Active.
inherited
-
setDeactivated()
→ void
-
Sets the state to
Deactivated.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited