dispose method

  1. @protected
  2. @override
void dispose()

Called by deactivate; should contain the actual object deactivation code.

If propose throws an Exception, the default Actor implementation will call dispose to clean up even a partially initialized object.

Implementation

@protected
@override
void dispose() {
  if (queryId != 0) {
    sqlite.free(queryId);
    queryId = 0;
  }
  super.dispose();
}