Scheme class
- Annotations
-
- @immutable
Constructors
- Scheme({int revision = schemeInitialRevision, DatabaseUpgrader? upgrader, required String kindPath, VirtualColumns virtualColumns = const [], PartialIndexes partialIndexes = const [], SearchIndexes searchIndexes = const []})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kindPath → String
-
final
- partialIndexes → PartialIndexes
-
final
- revision → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchIndexes → SearchIndexes
-
final
- upgrader → DatabaseUpgrader?
-
final
- virtualColumns → VirtualColumns
-
final
Methods
-
deactivateUpdatersLookup(
) → void -
elementsDefinition(
List< SchemeElement> elements) → Object -
getPartialIndex(
String name) → PartialIndex -
getSearchIndex(
String name) → SearchIndex -
getSearchIndexesUpdater(
Kind? kind) → SearchRowsUpdaters? -
getVirtualColumn(
String name) → VirtualColumn -
initializeUpdatersLookup(
SQLite sqlite) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDefinition(
) → StdMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kKindPath → const String
- kPartialIndexes → const String
- kRevision → const String
- kSearchIndexes → const String
- kVirtualColumns → const String