kindPath property
The JSON path to extract Kinds from database JSON values.
An application supplies data to the mapping table as key-value pairs,
where the "value" is a JSON value to be stored in the value column of
the mapping table. This property, kindPath, holds the JSON path used
to extract a Kind from each of those JSON values.
Changing this string changes the overall scheme version, which triggers a scheme migration procedure.
Implementation
final String kindPath;