virtualColumns property
A list of the generated virtual column descriptions.
If the VirtualColumn.sql or VirtualColumn.kinds of a column in this list change, the column's VirtualColumn.version must be increased to trigger a scheme migration. More formally, if the map composed of the name-version pairs of the virtualColumns has changed, then the overall scheme version changes and a scheme migration procedure is triggered.
If there is a need to create or rename a column, it is best to avoid new names that were used in old scheme versions, because a coincidence might arise if, e.g., one column is removed in the application update X and another is introduced immediately after under the same name and version in the update X+1 while a user skips the update X but installs X+1.
Implementation
final VirtualColumns virtualColumns;