name property
A string representing the name of the provided description.
A class derived from SchemeElement provides a description of a certain aspect of a Scheme. This name string, set by the application and associated with the description, is used internally by this library as an SQLite identifier within the corresponding DDL statements during database initialization or scheme migration.
Implementation
final String name;