version property
An integer representing the version of the provided description.
A class derived from SchemeElement provides a description of a certain aspect of a Scheme. As an application evolves, the Scheme it uses may need to change to meet application requirements. This version number, set by the application and associated with the description provided by a derived class, is used by this library to identify description changes in order to trigger scheme migrations.
Implementation
final int version;