SchemeMigrationPlan class base
Determines a sequence of logical actions to create or migrate a scheme.
This class is used internally by the library during scheme creation and migration procedures to identify which scheme elements must be removed, which must be created, whether revision upgrade callbacks must be called, and whether to create or recreate the kind column and its index.
Constructors
- SchemeMigrationPlan(StdMap stored, StdMap actual, Scheme scheme)
- Creates and initializes a SchemeMigrationPlan.
Properties
- actualKindPath ↔ String
-
The
KindJSON path of the scheme that the application expects.latefinal -
actualPartialIndexes
↔ Map<
String, int> -
The expected overall version of the PartialIndexes.
latefinal
- actualRevision ↔ int
-
The revision of the scheme that the application expects.
latefinal
-
actualSearchIndexes
↔ Map<
String, int> -
The expected overall version of the SearchIndexes.
latefinal
-
actualVirtualColumns
↔ Map<
String, int> -
The expected overall version of the VirtualColumns.
latefinal
- dropKindColumnAndIndex ↔ bool
-
Whether to remove the kind column and its index.
latefinal
-
dropPartialIndexes
→ Set<
String> -
The partial indexes to be removed.
final
-
dropSearchIndexes
→ Set<
String> -
The FTS indexes to be removed.
final
-
dropVirtualColumns
→ Set<
String> -
The virtual columns to be removed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- makeKindColumnAndIndex ↔ bool
-
Whether to create the kind column and its index.
latefinal
-
makePartialIndexes
→ Set<
String> -
The partial indexes to be created.
final
-
makeSearchIndexes
→ Set<
String> -
The FTS indexes to be created.
final
-
makeVirtualColumns
→ Set<
String> -
The virtual columns to be created.
final
- performRevisionUpgrade ↔ bool
-
Whether to call Scheme.upgrader callbacks.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storedKindPath ↔ String?
-
The
KindJSON path of the scheme loaded from the database.latefinal -
storedPartialIndexes
↔ Map<
String, int> -
The loaded overall version of the PartialIndexes.
latefinal
- storedRevision ↔ int?
-
The revision of the scheme loaded from the database.
latefinal
-
storedSearchIndexes
↔ Map<
String, int> -
The loaded overall version of the SearchIndexes.
latefinal
-
storedVirtualColumns
↔ Map<
String, int> -
The loaded overall version of the VirtualColumns.
latefinal
Methods
-
dump(
) → String - Returns a logging text with an overview of creation or migration actions.
-
getElementsMap(
StdMap scheme, String elements) → Map< String, int> - Returns a map representing the overall version of the SchemeElements.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortElementsMigration(
Map< String, int> stored, Map<String, int> actual, Set<String> drop, Set<String> make) → void - Determines initially which SchemeElements to remove and which to create.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited