SchemeMigrationPlan class
Constructors
- SchemeMigrationPlan(StdMap stored, StdMap actual, Scheme scheme)
Properties
- actualKindPath ↔ String
-
latefinal
-
actualPartialIndexes
↔ Map<
String, int> -
latefinal
- actualRevision ↔ int
-
latefinal
-
actualSearchIndexes
↔ Map<
String, int> -
latefinal
-
actualVirtualColumns
↔ Map<
String, int> -
latefinal
- dropKindColumnAndIndex ↔ bool
-
latefinal
-
dropPartialIndexes
→ Set<
String> -
final
-
dropSearchIndexes
→ Set<
String> -
final
-
dropVirtualColumns
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- makeKindColumnAndIndex ↔ bool
-
latefinal
-
makePartialIndexes
→ Set<
String> -
final
-
makeSearchIndexes
→ Set<
String> -
final
-
makeVirtualColumns
→ Set<
String> -
final
- performRevisionUpgrade ↔ bool
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storedKindPath ↔ String?
-
latefinal
-
storedPartialIndexes
↔ Map<
String, int> -
latefinal
- storedRevision ↔ int?
-
latefinal
-
storedSearchIndexes
↔ Map<
String, int> -
latefinal
-
storedVirtualColumns
↔ Map<
String, int> -
latefinal
Methods
-
dump(
) → String -
getElementsMap(
StdMap scheme, String elements) → Map< String, int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sortElementsMigration(
Map< String, int> stored, Map<String, int> actual, Set<String> drop, Set<String> make) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited