json property
Whether to store values of the described column as binary JSON.
If json is true, it is expected that values in this column are
well-formed JSON. They will be stored in a corresponding FTS table as
binary JSON. Such a column should also be configured as unindexed.
Implementation
final bool json;