SearchIndex class

Inheritance
Annotations
  • @immutable

Constructors

SearchIndex({required int version, required String name, required SearchColumns columns, required SearchRowGetters getters})

Properties

columns SearchColumns
final
columnsDefStr String
no setter
columnsStr String
no setter
getters SearchRowGetters
final
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
parameters String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updater SearchIndexUpdater
latefinal
version int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited