dispose method

  1. @protected
  2. @override
void dispose()

Called by deactivate; should contain the actual object deactivation code.

If propose throws an Exception, the default Actor implementation will call dispose to clean up even a partially initialized object.

Implementation

@protected
@override
void dispose() {
  _insert?.close();
  _insert = null;
  _update?.close();
  _update = null;
  _delete?.close();
  _delete = null;
  super.dispose();
}