SearchRow typedef
The return type of SearchRowGetter callbacks.
This type is a Map of Strings to Objects. It represents a row to be inserted or updated in an FTS index table. Keys correspond to FTS index column names, while values are used to form the row.
See also: SearchIndex.
Implementation
typedef SearchRow = Map<String, Object>;