VirtualColumn class
- Inheritance
-
- Object
- SchemeElement
- VirtualColumn
- Annotations
-
- @immutable
Constructors
- VirtualColumn({required int version, required String name, required KindList kinds, required SqlExpression expression})
Properties
- expression → SqlExpression
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kinds → KindList
-
final
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited