sql property
The expression whose result forms the value of the virtual column.
See VirtualColumn for information on how this property relates to the kinds property.
Implementation
final Sql sql;
The expression whose result forms the value of the virtual column.
See VirtualColumn for information on how this property relates to the kinds property.
final Sql sql;