SearchQueryConverter class base

Constructors

SearchQueryConverter({required List<String> pQueryColumns, required Map<String, List<String>> sQueryColumns})

Properties

hashCode int
The hash code for this object.
no setterinherited
pQueryColumns List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sQueryColumns Map<String, List<String>>
final

Methods

build() FtsParser
Builds the default composite parser starting at start.
buildFrom<T>(Parser<T> parser) → Parser<T>
Builds a composite parser starting with the specified parser.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() FtsParser
/
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited