SearchQueryConverter constructor
SearchQueryConverter({})
Creates a new SearchQueryConverter with the given arguments.
The arguments are as follows:
columnsis a list of the actual names of the FTS table columns to which FTS queries generated by this parser are limited;aliasesis a Map that defines custom column names recognized by this parser and maps each name to a substitution list of one or more actual column names found incolumns.
Names in columns are not recognized by the parser (unless they appear as
keys in aliases); only column names defined as keys in aliases are.
Implementation
SearchQueryConverter({required this.columns, required this.aliases});