aliases property
A Map that defines custom column names recognized by this parser.
This property maps each custom name to a substitution list of one or more actual column names found in the columns property. Only column names defined as keys in aliases are recognized by the parser.
Implementation
final Map<String, List<String>> aliases;